From 56a6e9787a87f57b9cc9da0f6f64abcd8a4a4a9a Mon Sep 17 00:00:00 2001
From: Svend Meyland Nicolaisen <svend.nicolaisen@nktphotonics.com>
Date: Sun, 16 Apr 2023 01:42:24 +0200
Subject: [PATCH] Recipes containing both git and npmsw sources in the SRC_URI
 fail during fetch from the shrinkwrap. It seems that when the fetcher is
 fetching from the shrinkwrap, the SRCREV variable has been deleted but it
 still ends up fetching from the git source resulting in an error because
 SRCREV is undefined. The root cause of this is that the Fetch class defaults
 to urls from the SRC_URI when the urls parameter contains an empty list. This
 patch will ensure that Fetch is not instantiated if the urls list is empty.

Signed-off-by: Svend Meyland Nicolaisen <svend.nicolaisen@nktphotonics.com>
---
 lib/bb/fetch2/npmsw.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/lib/bb/fetch2/npmsw.py b/lib/bb/fetch2/npmsw.py
index 36fcbfba..cc81100b 100644
--- a/lib/bb/fetch2/npmsw.py
+++ b/lib/bb/fetch2/npmsw.py
@@ -205,7 +205,9 @@ class NpmShrinkWrap(FetchMethod):
         # This fetcher resolves multiple URIs from a shrinkwrap file and then
         # forwards it to a proxy fetcher. The management of the donestamp file,
         # the lockfile and the checksums are forwarded to the proxy fetcher.
-        ud.proxy = Fetch([dep["url"] for dep in ud.deps if dep["url"]], data)
+        shrinkwrap_urls = [dep["url"] for dep in ud.deps if dep["url"]]
+        if shrinkwrap_urls:
+            ud.proxy = Fetch(shrinkwrap_urls, data)
         ud.needdonestamp = False
 
     @staticmethod
-- 
2.39.2.windows.1

